@@ -112,7 +112,7 @@ class App:
         self.container = container or BaseContainer(
             scopes=("app", "connection", "endpoint")
         )
-        register_framework_dependencies(self.container)
+        register_framework_dependencies(self.container, app=self, app_type=App)
         self._setup_run = False
 
         @asynccontextmanager
@@ -182,7 +182,6 @@ class App:
         receive: starlette.types.Receive,
         send: starlette.types.Send,
     ) -> None:
-        scope["app"] = self
         scope_type = scope["type"]
         if scope_type == "http" or scope_type == "websocket":
             if not self._setup_run:
