@@ -11,12 +11,13 @@ else:
 from pydantic.fields import ModelField
 from starlette.requests import HTTPConnection
 
+from xpresso._utils.typing import is_mapping_like, is_sequence_like
 from xpresso.binders._extractors.api import ParameterExtractorMarker
 from xpresso.binders._extractors.params.base import (
     ParameterExtractorBase,
     get_basic_param_info,
 )
-from xpresso.binders._extractors.utils import grouped, is_mapping_like, is_sequence_like
+from xpresso.binders._extractors.utils import grouped
 from xpresso.typing import Some
 
 
