@@ -3,8 +3,9 @@ import typing
 from dataclasses import dataclass
 
 from pydantic.fields import ModelField
-from pydantic.schema import field_schema, get_flat_models_from_field, get_model_name_map
+from pydantic.schema import get_flat_models_from_field
 
+from xpresso._utils.schemas import openapi_schema_from_pydantic_field
 from xpresso._utils.typing import model_field_from_param
 from xpresso.binders._openapi_providers.api import (
     ModelNameMap,
@@ -13,7 +14,6 @@ from xpresso.binders._openapi_providers.api import (
     Schemas,
 )
 from xpresso.openapi import models as openapi_models
-from xpresso.openapi.constants import REF_PREFIX
 
 
 @dataclass(frozen=True)
@@ -25,28 +25,16 @@ class OpenAPIFormField(OpenAPIBody):
     field: ModelField
     include_in_schema: bool
 
+    def get_models(self) -> typing.List[type]:
+        return list(get_flat_models_from_field(self.field, set()))
+
     def get_field_name(self) -> str:
         return self.name
 
     def get_schema(
         self, model_name_map: ModelNameMap, schemas: Schemas
     ) -> openapi_models.Schema:
-        model_name_map.update(
-            get_model_name_map(
-                get_flat_models_from_field(
-                    self.field,
-                    model_name_map.keys(),  # type: ignore[arg-type]
-                )
-            )
-        )
-        schema, refs, _ = field_schema(
-            self.field,
-            by_alias=True,
-            ref_prefix=REF_PREFIX,
-            model_name_map=model_name_map,
-        )
-        schemas.update(refs)
-        return openapi_models.Schema(**schema)
+        return openapi_schema_from_pydantic_field(self.field, model_name_map, schemas)
 
     def get_encoding(self) -> typing.Optional[openapi_models.Encoding]:
         return openapi_models.Encoding(
